
Bardeen
===============================

This package contains some Python utility functions for scientific stuff.

Development by me is halted, but I'll accept pull requests if you have useful additions.

    pip install bardeen


